@@ -35,7 +35,7 @@ def get_download_url(key):
     """
     url = backends.get_backend().get_download_url(key)
     if not url:
-        logger.warning('FileUploadError: Could not retrieve URL for key {}'.format(key))
+        logger.warning('FileUploadError: Could not retrieve URL for key %s', key)
     return url
 
 
@@ -88,7 +88,7 @@ def can_delete_file(current_user_id, teams_enabled, key, team_id=None, shared_fi
         try:
             shared_file = SharedFileUpload.by_key(key)
         except SharedFileUpload.DoesNotExist:
-            logger.info('While checking ORA file-deletion ability, could not find file with key: {}'.format(key))
+            logger.info('While checking ORA file-deletion ability, could not find file with key: %s', key)
             return True
 
     if shared_file.owner_id != current_user_id:
@@ -122,10 +122,9 @@ def _safe_load_json_list(field, log_error=False):
         return json.loads(field)
     except ValueError:
         if log_error:
-            logger.exception("URLWorkaround: Safe Load failed for data field:{field} with type:{type}".format(
-                field=field,
-                type=type(field)
-            ))
+            logger.exception(
+                "URLWorkaround: Safe Load failed for data field:%s with type:%s", field, type(field)
+            )
         return []
 
 
@@ -169,10 +168,12 @@ class FileUpload:
             try:
                 return get_download_url(self.key)
             except FileUploadError as exc:
-                logger.exception('FileUploadError: URL retrieval failed for key {key} with error {error}'.format(
-                    key=self.key,
-                    error=exc
-                ))
+                logger.exception(
+                    'FileUploadError: URL retrieval failed for key %s with error %s',
+                    self.key,
+                    exc,
+                    exc_info=True,
+                )
                 return ''
         return None
 
@@ -210,6 +211,12 @@ class FileUpload:
         """
         return self._to_dict() == other._to_dict()  # pylint: disable=protected-access
 
+    def __hash__(self):
+        """
+        Returns a hash of the FileUpload's dict representation
+        """
+        return hash(self._to_dict())
+
 
 FileDescriptor = namedtuple('FileDescriptor', ['download_url', 'description', 'name', 'show_delete_button'])
 TeamFileDescriptor = namedtuple('TeamFileDescriptor', ['download_url', 'description', 'name', 'uploaded_by'])
@@ -412,10 +419,11 @@ class FileUploadManager:
                 sizes_to_add,
             ) = self._dicts_to_key_lists(new_uploads, required_keys)
         except FileUploadError as exc:
-            logging.exception("FileUploadError: Metadata save for {data} failed with error {error}".format(
-                error=exc,
-                data=new_uploads
-            ))
+            logging.exception(
+                "FileUploadError: Metadata save for %s failed with error %s",
+                exc,
+                new_uploads
+            )
             raise
 
         existing_file_descriptions, existing_file_names, existing_file_sizes = self._get_metadata_from_block()
@@ -494,7 +502,7 @@ class FileUploadManager:
             try:
                 SharedFileUpload.by_key(file_key).delete()
             except SharedFileUpload.DoesNotExist:
-                logger.warning('Could not find SharedFileUpload to delete: {}'.format(file_key))
+                logger.warning('Could not find SharedFileUpload to delete: %s', file_key)
 
         self.invalidate_cached_shared_file_dicts()
 
